import Typography from "@/shared/ui/components/Typography/Typography";
import "./AboutUs.scss";
import Image from "next/image";
import header from "./assets/header.svg";
import { Metadata } from "next";
import BreadCrumbs from "@/features/BreadCrumbs/BreadCrumbs";
import { apiInstance } from "@/shared/config/apiConfig";
import { IMetatag } from "@/shared/types/metatag-type";

export async function generateMetadata(): Promise<Metadata> {
  const data = await apiInstance
    .get<IMetatag[]>("/metatags/")
    .then((res) => res.data)
    .catch((e) => console.log(e));

  if (!data)
    return {
      title: "KG ROAD | О нас",
      description:
        "Transparency International - Кыргызстан - филиал международной организации Transparency International в Кыргызской Республике.",
      openGraph: {
        title: "KG ROAD | О нас",
        description:
          "Transparency International - Кыргызстан - филиал международной организации Transparency International в Кыргызской Республике.",
      },
    };

  const metadata = data.filter((tag) => tag.page === "about-us")[0];
  if (!metadata) {
    return {
      title: "KG ROAD | О нас",
      description:
        "Transparency International - Кыргызстан - филиал международной организации Transparency International в Кыргызской Республике.",
      openGraph: {
        title: "KG ROAD | О нас",
        description:
          "Transparency International - Кыргызстан - филиал международной организации Transparency International в Кыргызской Республике.",
      },
    };
  }

  return {
    title: `KG ROAD | ${metadata.title}`,
    description: metadata.description,
    keywords: metadata.keywords.split(","),
    openGraph: {
      title: `KG ROAD | ${metadata.title}`,
      description: metadata.description,
      type: "website",
    },
  };
}

const AboutUs = () => {
  return (
    <div className="about-us page-padding">
      <BreadCrumbs homeRequired />
      <Typography element="h2">О нас</Typography>

      <Image
        className="about-us__image"
        src={header}
        alt="Header Image"
      />
      <div className="about-us__descriptions">
        <h3>
          Transparency International-Кыргызстан - филиал международной
          организации Transparency International в Кыргызской
          Республике.
        </h3>
        <h3>Миссия ТИ-Кыргызстан</h3>
        <p>
          Продвижение эффективной общественной политики и надлежащего
          управления в целях предотвращения коррупции и усиления
          демократии в стране.{" "}
        </p>
        <h3>Цели и приоритеты ТИ-Кыргызстан:</h3>
        <ul>
          <li>
            - антикоррупционное просвещение населения, повышение
            общественного осознания значимости и важности борьбы с
            коррупцией в Кыргызстане;
          </li>
          <li>
            - организация изучения практики и теории борьбы с
            коррупцией и участия в ней структур гражданского общества
            в Кыргызстане и других странах;
          </li>
          <li>
            - содействие гражданам и организациям в реализации их
            конституционных прав и свобод;
          </li>
          <li>
            - преимущественная ориентация на международный опыт
            уменьшения коррупции, освоение его технологий, ресурсов, а
            также включение структур гражданского общества в
            международный диалог борьбы с коррупцией.
          </li>
        </ul>
      </div>
      <p className="about-us__author">
        Photo By Mzximvs VdB from Brussels, belgium - Road to
        Issyk-Kul (south shore), CC BY-SA 2.0
      </p>
    </div>
  );
};

export default AboutUs;
